.. module:: wwdtm.host

************
Module: host
************

This module provides objects used to retrieve hosts, host information and host
details from a copy of the Wait Wait Don't Tell Me! Stats database.

Host
====

.. autoclass:: wwdtm.host.Host
    :members:
    :inherited-members:

HostAppearances
===============

.. autoclass:: wwdtm.host.HostAppearances
    :members:
    :inherited-members:

HostUtility
===========

.. autoclass:: wwdtm.host.HostUtility
    :members:
    :inherited-members:
